@@ -128,13 +128,17 @@ impl<I: Input> Tokens for Lexer<'_, I> {
         self.target
     }
 
+    fn start_pos(&self) -> BytePos {
+        self.start_pos
+    }
+
     fn set_expr_allowed(&mut self, allow: bool) {
         self.set_expr_allowed(allow)
     }
-
     fn token_context(&self) -> &TokenContexts {
         &self.state.context
     }
+
     fn token_context_mut(&mut self) -> &mut TokenContexts {
         &mut self.state.context
     }
@@ -147,10 +151,6 @@ impl<I: Input> Tokens for Lexer<'_, I> {
         self.errors.borrow_mut().push(error);
     }
 
-    fn take_errors(&mut self) -> Vec<Error> {
-        take(&mut self.errors.borrow_mut())
-    }
-
     fn add_module_mode_error(&self, error: Error) {
         if self.ctx.module {
             self.add_error(error);
@@ -158,6 +158,10 @@ impl<I: Input> Tokens for Lexer<'_, I> {
         }
         self.module_errors.borrow_mut().push(error);
     }
+
+    fn take_errors(&mut self) -> Vec<Error> {
+        take(&mut self.errors.borrow_mut())
+    }
 }
 
 impl<'a, I: Input> Iterator for Lexer<'a, I> {
@@ -194,7 +198,7 @@ impl<'a, I: Input> Iterator for Lexer<'a, I> {
                             // if the file had no tokens and no shebang, then treat any
                             // comments in the leading comments buffer as leading.
                             // Otherwise treat them as trailing.
-                            if last == BytePos(0) {
+                            if last == self.start_pos {
                                 comments_buffer.push(BufferedComment {
                                     kind: BufferedCommentKind::Leading,
                                     pos: last,
@@ -320,12 +324,12 @@ impl<'a, I: Input> Iterator for Lexer<'a, I> {
 }
 
 impl State {
-    pub fn new(syntax: Syntax) -> Self {
+    pub fn new(syntax: Syntax, start_pos: BytePos) -> Self {
         State {
             is_expr_allowed: true,
             is_first: true,
             had_line_break: false,
-            prev_hi: BytePos(0),
+            prev_hi: start_pos,
             context: TokenContexts(vec![TokenContext::BraceStmt]),
             token_type: None,
             start: BytePos(0),
